public inbox for frysk-cvs@sourceware.org
help / color / mirror / Atom feed
* [SCM]  master: Replace TestTypeEntry.java with TestTypeEntry.java-sh.
@ 2007-12-03  3:12 scox
  0 siblings, 0 replies; only message in thread
From: scox @ 2007-12-03  3:12 UTC (permalink / raw)
  To: frysk-cvs

The branch, master has been updated
       via  3e0d9c8797162375a29c000a1f59aa6baee8d18d (commit)
       via  e1a13c24e7064b8b391772b31df0663d40cc63c4 (commit)
      from  85c5359c1e019afb16137186f5daf59cb2c2ab55 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email.

- Log -----------------------------------------------------------------
commit 3e0d9c8797162375a29c000a1f59aa6baee8d18d
Author: Stan Cox <scox@redhat.com>
Date:   Sun Dec 2 21:54:54 2007 -0500

    Replace TestTypeEntry.java with TestTypeEntry.java-sh.
    
    * TestTypeEntry.java-sh: New.

commit e1a13c24e7064b8b391772b31df0663d40cc63c4
Author: Stan Cox <scox@redhat.com>
Date:   Sun Dec 2 21:45:26 2007 -0500

    Replace TestTypeEntry.java-sh with TestTypeEntry.java
    
    * TestTypeEntryType.java-sh: Delete.
    * TestTypeEntryValue.java-sh: Delete.
    * TestTypeEntry.java: Delete
    * TestTypeEntry.java-sh: New.
    * gen-type-expect-tests.py (j.open):  Remove reference to tool.
    (j.prologue): Rename TypeTestbed.  Add checkType and checkValue.
    Remove compareEqual and class Expect.
    (j.add_test) Remove reference to tool.
    * funit-array.c: Delete.
    * funit-enum.c: Delete.
    * funit-scalar.c: Delete.
    * funit-struct.c: Delete.

-----------------------------------------------------------------------

Summary of changes:
 frysk-core/frysk/debuginfo/ChangeLog               |   11 +
 frysk-core/frysk/debuginfo/TestTypeEntry.java      |  281 --------------------
 frysk-core/frysk/debuginfo/TestTypeEntry.java-sh   |    5 +
 .../frysk/debuginfo/TestTypeEntryType.java-sh      |    5 -
 .../frysk/debuginfo/TestTypeEntryValue.java-sh     |    3 -
 .../frysk/debuginfo/gen-type-expect-tests.py       |  180 +++++--------
 frysk-core/frysk/pkglibdir/ChangeLog               |    7 +
 frysk-core/frysk/pkglibdir/funit-array.c           |   87 ------
 frysk-core/frysk/pkglibdir/funit-class.cxx         |    2 +-
 frysk-core/frysk/pkglibdir/funit-enum.c            |   43 ---
 frysk-core/frysk/pkglibdir/funit-scalar.c          |   96 -------
 frysk-core/frysk/pkglibdir/funit-struct.c          |   70 -----
 12 files changed, 87 insertions(+), 703 deletions(-)
 delete mode 100644 frysk-core/frysk/debuginfo/TestTypeEntry.java
 create mode 100644 frysk-core/frysk/debuginfo/TestTypeEntry.java-sh
 delete mode 100644 frysk-core/frysk/debuginfo/TestTypeEntryType.java-sh
 delete mode 100644 frysk-core/frysk/debuginfo/TestTypeEntryValue.java-sh
 delete mode 100644 frysk-core/frysk/pkglibdir/funit-array.c
 delete mode 100644 frysk-core/frysk/pkglibdir/funit-enum.c
 delete mode 100644 frysk-core/frysk/pkglibdir/funit-scalar.c
 delete mode 100644 frysk-core/frysk/pkglibdir/funit-struct.c

First 500 lines of diff:
diff --git a/frysk-core/frysk/debuginfo/ChangeLog b/frysk-core/frysk/debuginfo/ChangeLog
index f3939c7..1a6cbe0 100644
--- a/frysk-core/frysk/debuginfo/ChangeLog
+++ b/frysk-core/frysk/debuginfo/ChangeLog
@@ -1,3 +1,14 @@
+2007-12-02  Stan Cox  <scox@redhat.com>
+
+	* TestTypeEntryType.java-sh: Delete.
+	* TestTypeEntryValue.java-sh: Delete.
+	* TestTypeEntry.java: Delete
+	* TestTypeEntry.java-sh: New.
+	* gen-type-expect-tests.py (j.open):  Remove reference to tool.
+	(j.prologue): Rename TypeTestbed.  Add checkType and checkValue.
+	Remove compareEqual and class Expect.
+	(j.add_test) Remove reference to tool.
+
 2007-11-30  Teresa Thomas  <tthomas@redhat.com>
 
 	* LocationExpression.java: Update, Comments added. 
diff --git a/frysk-core/frysk/debuginfo/TestTypeEntry.java b/frysk-core/frysk/debuginfo/TestTypeEntry.java
deleted file mode 100644
index 371e08e..0000000
--- a/frysk-core/frysk/debuginfo/TestTypeEntry.java
+++ /dev/null
@@ -1,281 +0,0 @@
-// This file is part of the program FRYSK.
-//
-// Copyright 2007, Red Hat Inc.
-//
-// FRYSK is free software; you can redistribute it and/or modify it
-// under the terms of the GNU General Public License as published by
-// the Free Software Foundation; version 2 of the License.
-//
-// FRYSK is distributed in the hope that it will be useful, but
-// WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-// General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with FRYSK; if not, write to the Free Software Foundation,
-// Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
-// 
-// In addition, as a special exception, Red Hat, Inc. gives You the
-// additional right to link the code of FRYSK with code not covered
-// under the GNU General Public License ("Non-GPL Code") and to
-// distribute linked combinations including the two, subject to the
-// limitations in this paragraph. Non-GPL Code permitted under this
-// exception must only link to the code of FRYSK through those well
-// defined interfaces identified in the file named EXCEPTION found in
-// the source code files (the "Approved Interfaces"). The files of
-// Non-GPL Code may instantiate templates or use macros or inline
-// functions from the Approved Interfaces without causing the
-// resulting work to be covered by the GNU General Public
-// License. Only Red Hat, Inc. may make changes or additions to the
-// list of Approved Interfaces. You must obey the GNU General Public
-// License in all respects for all of the FRYSK code and other code
-// used in conjunction with FRYSK except the Non-GPL Code covered by
-// this exception. If you modify this file, you may extend this
-// exception to your version of the file, but you are not obligated to
-// do so. If you do not wish to provide this exception without
-// modification, you must delete this exception statement from your
-// version and license this file solely under the GPL without
-// exception.
-
-package frysk.debuginfo;
-
-import java.util.Iterator;
-import java.util.logging.Logger;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
-
-import lib.dwfl.DwarfDie;
-import lib.dwfl.Dwfl;
-import lib.dwfl.DwflDieBias;
-import frysk.dwfl.DwflCache;
-import frysk.proc.Task;
-import frysk.testbed.DaemonBlockedAtSignal;
-import frysk.testbed.TestLib;
-import frysk.value.CompositeType;
-import frysk.value.Type;
-import frysk.value.CompositeType.DynamicMember;
-import frysk.value.CompositeType.Member;
-import frysk.value.CompositeType.StaticMember;
-
-public class TestTypeEntry
-    extends TestLib
-{
-    private class Expect
-    {
-	String symbol;
-	String output;
-	Expect (String symbol, String expect)
-	{
-	    this.symbol = symbol;
-	    this.output = expect;
-	}
-    }
-  Logger logger = Logger.getLogger("frysk");
-
-  public void testScalar () {
-      Expect [] expect  = {
-	      new Expect("long_21", "long int"),
-	      new Expect("int_21","int"),
-	      new Expect("int_22", "volatile simode"),
-	      new Expect("static_int", "int"),
-	      new Expect("int_p", "volatile int *"),
-	      new Expect("short_21", "short int"),
-	      new Expect("char_21", "char"),
-	      new Expect("float_21", "float"),
-	      new Expect("double_21", "double"),
-      };
-  
-      Task task = (new DaemonBlockedAtSignal("funit-scalar")).getMainTask();
-      
-      DebugInfoFrame frame = DebugInfoStackFactory.createVirtualStackTrace(task);
-      Dwfl dwfl;
-      DwarfDie[] allDies;
-      Type varType;
-      DwarfDie varDie;
-      long pc = frame.getAdjustedAddress();
-      dwfl = DwflCache.getDwfl(frame.getTask());
-      DwflDieBias bias = dwfl.getCompilationUnit(pc);
-      DwarfDie die = bias.die;
-      allDies = die.getScopes(pc - bias.bias);
-      TypeEntry typeEntry = new TypeEntry(frame.getTask().getISA());
-    
-      for (int i = 0; i < expect.length; i++) {
-	  varDie = die.getScopeVar(allDies, expect[i].symbol);
-	  assertNotNull(varDie);
-	  varType = typeEntry.getType(varDie.getType());
-	  assertNotNull(varType);
-	  assertEquals("testScalar " + expect[i].symbol, expect[i].output, varType.toPrint());
-      }
-  }
-
-  public void testArray () {
-      Expect[] expect = {
-	      new Expect("arr_1", "long int [32]"),
-	      new Expect("arr_2","int [5][6]"),
-	      new Expect("arr_3", "float [4][5]"),
-	      new Expect("arr_4", "char [4]"),
-      };
-  
-      Task task = (new DaemonBlockedAtSignal("funit-array")).getMainTask();
-      
-      DebugInfoFrame frame = DebugInfoStackFactory.createVirtualStackTrace(task);
-      Dwfl dwfl;
-      DwarfDie[] allDies;
-      Type varType;
-      DwarfDie varDie;
-      long pc = frame.getAdjustedAddress();
-      dwfl = DwflCache.getDwfl(frame.getTask());
-      DwflDieBias bias = dwfl.getCompilationUnit(pc);
-      DwarfDie die = bias.die;
-      allDies = die.getScopes(pc - bias.bias);
-      TypeEntry typeEntry = new TypeEntry(frame.getTask().getISA());
-    
-      for (int i = 0; i < expect.length; i++) {
-	  varDie = die.getScopeVar(allDies, expect[i].symbol);
-	  assertNotNull(varDie);
-	  varType = typeEntry.getType(varDie.getType());
-	  assertNotNull(varType);
-	  assertEquals("testArray " + expect[i].symbol, expect[i].output, varType.toPrint());
-      }
-  }
-
-  public void testEnum () {
-      if (unresolved(4998))
-	  return;
-
-      Expect[] expect = {
-	      new Expect("sportscar", ".*enum.*bmw=0.*porsche=1.*"),
-	      new Expect("ssportscar", ".*enum.*bmw.*porsche.*"),
-      };
-  
-      Task task = (new DaemonBlockedAtSignal("funit-enum")).getMainTask();
-      DebugInfoFrame frame = DebugInfoStackFactory.createVirtualStackTrace(task);
-      Dwfl dwfl;
-      DwarfDie[] allDies;
-      Type varType;
-      DwarfDie varDie;
-      long pc = frame.getAdjustedAddress();
-      dwfl = DwflCache.getDwfl(frame.getTask());
-      DwflDieBias bias = dwfl.getCompilationUnit(pc);
-      DwarfDie die = bias.die;
-      allDies = die.getScopes(pc - bias.bias);
-      TypeEntry typeEntry = new TypeEntry(frame.getTask().getISA());
-    
-      for (int i = 0; i < expect.length; i++) {
-	  varDie = die.getScopeVar(allDies, expect[i].symbol);
-	  if (varDie == null)
-	      varDie = DwarfDie.getDeclCU(allDies, expect[i].symbol);
-	  if (varDie == null) {
-	      continue;
-	  }
-	  varType = typeEntry.getType(varDie.getType());
-	  Pattern p = Pattern.compile(expect[i].output, Pattern.DOTALL);
-	  Matcher m = p.matcher(varType.toPrint());
-	  assertTrue("testEnum " + expect[i].symbol, m.matches());
-      }
-  }
-
-  public void testStruct () {
-      Expect[] expect = {
-	      new Expect("static_class", ".*static_class_t.*"),
-	      new Expect("class_1", ".*static_class_t.*"),
-	      new Expect("class_2", ".*c1;.*c2;.*"),
-	      new Expect("class_3", ".*int.*arr.*.2..2..*"),
-	      new Expect("class_4", ".*int x;.*float y;.*"),
-	      new Expect("class_5", ".*simode.*x;.*float.*y;.*"),
-	      new Expect("union_1", ".*union_t.*"),
-	      new Expect("class_p", ".*static_class_t.*"),
-      };
-  
-      Task task = (new DaemonBlockedAtSignal("funit-struct")).getMainTask();
-
-      DebugInfoFrame frame = DebugInfoStackFactory.createVirtualStackTrace(task);
-      Dwfl dwfl;
-      DwarfDie[] allDies;
-      Type varType;
-      DwarfDie varDie;
-      long pc = frame.getAdjustedAddress();
-      dwfl = DwflCache.getDwfl(frame.getTask());
-      DwflDieBias bias = dwfl.getCompilationUnit(pc);
-      DwarfDie die = bias.die;
-      allDies = die.getScopes(pc - bias.bias);
-      TypeEntry typeEntry = new TypeEntry(frame.getTask().getISA());
-    
-      for (int i = 0; i < expect.length; i++) {
-	  varDie = die.getScopeVar(allDies, expect[i].symbol);
-	  varType = typeEntry.getType(varDie.getType());
-	  Pattern p = Pattern.compile(expect[i].output, Pattern.DOTALL);
-	  Matcher m = p.matcher(varType.toPrint());
-	  assertTrue("testStruct " + expect[i].symbol, m.matches());
-      }
-  }
-
-  public void testClass () {
-      Expect[] expect = {
-	      new Expect("mb", ".*public:.*char.*\\*.*msg;.*void.*Base1.*"
-		      + "char.*\\*.*void.*~Base1.*char.*\\*.*msg;.*" 
-		      + "void.*Base2.*char.*\\*.*void.*~Base2.*private:.*"
-		      + "char.*\\*.*note;.*void.*Type.*char.*\\*.*char.*\\*.*"
-		      + "char.*void.*~Type.*"
-		      )
-      };
-  
-      Task task = (new DaemonBlockedAtSignal("funit-class")).getMainTask();
-
-      DebugInfoFrame frame = DebugInfoStackFactory.createVirtualStackTrace(task);
-     
-
-      Dwfl dwfl;
-      DwarfDie[] allDies;
-      Type varType;
-      DwarfDie varDie;
-      long pc = frame.getAdjustedAddress();
-      dwfl = DwflCache.getDwfl(frame.getTask());
-      DwflDieBias bias = dwfl.getCompilationUnit(pc);
-      DwarfDie die = bias.die;
-      allDies = die.getScopes(pc - bias.bias);
-      TypeEntry typeEntry = new TypeEntry(frame.getTask().getISA());
-    
-      for (int i = 0; i < expect.length; i++) {
-	  varDie = die.getScopeVar(allDies, expect[i].symbol);
-	  varType = typeEntry.getType(varDie.getType());
-	  Pattern p = Pattern.compile(expect[i].output, Pattern.DOTALL);
-	  Matcher m = p.matcher(varType.toPrint());
-	  assertTrue("testClass " + expect[i].symbol, m.matches());
-      }
-  }
-  
-  public void testClassWithStaticMembers () {
-
-      Task task = (new DaemonBlockedAtSignal("funit-class-static")).getMainTask();
-
-      DebugInfoFrame frame = DebugInfoStackFactory.createVirtualStackTrace(task);
-      
-      CompositeType compositeType = (CompositeType) frame.getSubprogram().getComposite().getType();
-      
-      assertNotNull("Retrieved type successfully", compositeType);
-      
-      Iterator iterator = compositeType.iterator();
-      
-      while(iterator.hasNext()){
-	  Member member = (Member) iterator.next();
-	  
-	  if(member.getName().equals("i")){
-	      assertTrue("Member " + member.getName() + " has the correct class", member instanceof DynamicMember);
-	  }
-	
-	  if(member.getName().equals("static_i")){
-	      assertTrue("Member " + member.getName() + " has the correct class", member instanceof StaticMember);
-	  }
-	
-	  if(member.getName().equals("crash")){
-	      assertTrue("Member " + member.getName() + " has the correct class", member instanceof DynamicMember);
-	  }
-	
-	  if(member.getName().equals("static_crash")){
-	      assertTrue("Member " + member.getName() + " has the correct class", member instanceof StaticMember);
-	  }
-      }
-  }
-
-}  
diff --git a/frysk-core/frysk/debuginfo/TestTypeEntry.java-sh b/frysk-core/frysk/debuginfo/TestTypeEntry.java-sh
new file mode 100644
index 0000000..5a38c37
--- /dev/null
+++ b/frysk-core/frysk/debuginfo/TestTypeEntry.java-sh
@@ -0,0 +1,5 @@
+#!/bin/sh
+
+python $(dirname $0)/gen-type-expect-tests.py frysk/pkglibdir/funit-type-entry.c $(dirname $0)/../pkglibdir/funit-class.cxx
+
+
diff --git a/frysk-core/frysk/debuginfo/TestTypeEntryType.java-sh b/frysk-core/frysk/debuginfo/TestTypeEntryType.java-sh
deleted file mode 100644
index 9911fad..0000000
--- a/frysk-core/frysk/debuginfo/TestTypeEntryType.java-sh
+++ /dev/null
@@ -1,5 +0,0 @@
-#!/bin/sh
-
-python $(dirname $0)/gen-type-expect-tests.py -type frysk/pkglibdir/funit-type-entry.c $(dirname $0)/../pkglibdir/funit-class.cxx
-
-
diff --git a/frysk-core/frysk/debuginfo/TestTypeEntryValue.java-sh b/frysk-core/frysk/debuginfo/TestTypeEntryValue.java-sh
deleted file mode 100644
index de20fbe..0000000
--- a/frysk-core/frysk/debuginfo/TestTypeEntryValue.java-sh
+++ /dev/null
@@ -1,3 +0,0 @@
-#!/bin/sh
-
-python $(dirname $0)/gen-type-expect-tests.py -value frysk/pkglibdir/funit-type-entry.c $(dirname $0)/../pkglibdir/funit-class.cxx
diff --git a/frysk-core/frysk/debuginfo/gen-type-expect-tests.py b/frysk-core/frysk/debuginfo/gen-type-expect-tests.py
index ef2690f..3bfa97d 100644
--- a/frysk-core/frysk/debuginfo/gen-type-expect-tests.py
+++ b/frysk-core/frysk/debuginfo/gen-type-expect-tests.py
@@ -46,10 +46,8 @@ import os,sys
 ########################################################################
 
 class j:
-    def open(self,name):
-#       self.j_file = open("/tmp/TestTypeEntry" + name.capitalize() + ".java", 'w')
-        self.tool = name
-        self.name = "TestTypeEntry" + name.capitalize()
+    def open(self):
+        self.name = "TestTypeEntry"
     def write(self,str):
         print str
     def prologue(self,):
@@ -57,8 +55,8 @@ class j:
 
 package frysk.debuginfo;
 
+import java.io.*;
 import java.util.logging.Logger;
-
 import lib.dwfl.DwarfDie;
 import lib.dwfl.Dwfl;
 import lib.dwfl.DwflDieBias;
@@ -66,29 +64,23 @@ import frysk.dwfl.DwflCache;
 import frysk.proc.Task;
 import frysk.testbed.DaemonBlockedAtSignal;
 import frysk.testbed.TestLib;
-''')
-        if (self.tool == "value"):
-            print('''
-import java.io.*;
+import frysk.value.Type;
 import frysk.value.Value;
 import frysk.value.Format;
 import frysk.debuginfo.DebugInfo;
 ''')
-        elif (self.tool == "type"):
-            print('''
-import frysk.value.Type;
-''')
             
         print('''
 public class %s extends TestLib {
-    private class ExpectTest {
+    private class TypeTestbed {
 	DebugInfoFrame frame;
         Task task;
 	DwarfDie die;
 	DwarfDie[] allDies;
 	TypeEntry typeEntry;
+	String testName;
 
-	ExpectTest(String executable) {
+	TypeTestbed(String executable, String testName) {
 	    task = new DaemonBlockedAtSignal(executable).getMainTask();
             frame = DebugInfoStackFactory.createDebugInfoStackTrace(task);
 	    long pc = frame.getAdjustedAddress();
@@ -97,116 +89,85 @@ public class %s extends TestLib {
 	    die = bias.die;
 	    allDies = die.getScopes(pc - bias.bias);
 	    typeEntry = new TypeEntry(frame.getTask().getISA());
+	    this.testName = testName;
 	}
 ''' % (self.name))
 	
-        if (self.tool == "type"):
-            print('''
-	void compareEqual(Expect[] expect, String myName) {
-	     Type varType;
-	    
-	     for (int i = 0; i < expect.length; i++) {
-		 DwarfDie varDie = die.getScopeVar(allDies, expect[i].symbol);
-                 if (varDie == null)
-                     System.out.println("Error: Cannot find " + expect[i].symbol);
-		 assertNotNull(varDie);
-		 varType = typeEntry.getType(varDie.getType());
-		 assertNotNull(varType);
-                 // System.out.println("Expect: " + expect[i].symbol + "\\n'" +
-                 //    expect[i].output + "'\\nGot:\\n'" + varType.toPrint());
-		 assertEquals(myName + expect[i].symbol, expect[i].output, varType.toPrint());
-	     }
+        print('''
+	void checkType(String symbol, String expected) {
+	    Type varType;
+
+	    DwarfDie varDie = die.getScopeVar(allDies, symbol);
+	    if (varDie == null)
+		System.out.println("Error: Cannot find " + symbol);
+	    assertNotNull(varDie);
+	    varType = typeEntry.getType(varDie.getType());
+	    assertNotNull(varType);
+	    // System.out.println("Expect: " + symbol + "\\n'" +
+	    //    expected + "'\\nGot:\\n'" + varType.toPrint());
+	    assertEquals(testName + symbol, expected, varType.toPrint());
 	}
-    }
-''')
-        elif (self.tool == "value"):
-            print('''
-        void compareEqual(Expect[] expect, String myName) {
+
+        void checkValue(String symbol, String expected) {
             // "Print" to a byte array
 	    ByteArrayOutputStream baos = new ByteArrayOutputStream(32);
 	    PrintWriter pw = new PrintWriter(baos, true);
-	    for (int i = 0; i < expect.length; i++) {
-                // ??? cache address of x so &x can be checked?
-	        if (expect[i].output.indexOf("&") >= 0
-                    || expect[i].symbol.indexOf("ptr") >= 0
-		    || expect[i].output.length() == 0)
-		    continue;
-                DwarfDie varDie = die.getScopeVar(allDies, expect[i].symbol);
-                if (varDie == null)
-                    System.out.println("Error: Cannot find " + expect[i].symbol);
-                assertNotNull(varDie);
-		DebugInfo debugInfo = new DebugInfo(frame);
-                Value value =  debugInfo.print(expect[i].symbol, frame);
-                value.toPrint(pw, task.getMemory(), Format.NATURAL, 0);
-                pw.flush();
-                String valueString = baos.toString();
-                // System.out.println("Expect: " + expect[i].symbol +
-                //     "\\n'" + expect[i].output + "'\\nGot:\\n'" +
-                //     valueString + "'" + " " + value.getType());
-                assertEquals(myName + expect[i].symbol, expect[i].output, valueString);
-                baos.reset();
-            }
+	    // ??? cache address of x so &x can be checked?
+	    if (expected.indexOf("&") >= 0 || symbol.indexOf("ptr") >= 0
+		|| expected.length() == 0)
+		return;
+	    DwarfDie varDie = die.getScopeVar(allDies, symbol);
+	    if (varDie == null)
+		System.out.println("Error: Cannot find " + symbol);
+	    assertNotNull(varDie);
+	    DebugInfo debugInfo = new DebugInfo(frame);
+	    Value value =  debugInfo.print(symbol, frame);
+	    value.toPrint(pw, task.getMemory(), Format.NATURAL, 0);
+	    pw.flush();
+	    String valueString = baos.toString();
+	    // System.out.println("Expect: " + symbol +
+	    //     "\\n'" + expected + "'\\nGot:\\n'" +
+	    //     valueString + "'" + " " + value.getType());
+	    assertEquals(testName + symbol, expected, valueString);
+	    baos.reset();
 	}
     }
 ''')
 
         print('''
-    private class Expect
-    {
-	String symbol;
-	String output;
-	Expect (String symbol, String expect)
-	{
-	    this.symbol = symbol;
-	    this.output = expect;
-	}
-    }


hooks/post-receive
--
frysk system monitor/debugger


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2007-12-03  3:12 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2007-12-03  3:12 [SCM] master: Replace TestTypeEntry.java with TestTypeEntry.java-sh scox

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).